<?php
/*
Plugin Name: Toggle Mobile Menu Plugin
Plugin URI: https://fischercreativemedia.com
Description: Plugin to use a Toggle Style Mobile Menu
Version: 2.0.0
Author: Don Fischer
Author URI: https://www.fischercreativemedia.com/
Donate link: https://www.fischercreativemedia.com/wordpress-plugins/donate/
Requires at least: 3.8
Tested up to: 5.8.1
Text Domain: toggle-menu-mobile
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html

 * Copyright (C)2016-2021 Donald J Fischer
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the [GNU General Public License](http://wordpress.org/about/gpl/)
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * on an "AS IS", but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see [GNU General Public Licenses](http://www.gnu.org/licenses/),
 * or write to the Free Software Foundation, Inc., 51 Franklin Street,
 * Fifth Floor, Boston, MA 02110-1301, USA.
*/
//Required for plugin update
require_once( plugin_dir_path( __FILE__ ) . '/updates/plugin-update-checker.php' );
new FCMPluginUpdateChecker_1_7( 'https://graphiccaffeine.com/wp-admin/admin-ajax.php', __FILE__ );

// Auto update variables
add_filter( 'all_plugins', function ( $plugins ) {
  if ( isset( $plugins[ 'toggle-menu-mobile/toggle-menu-mobile.php' ] ) ) {
    $plugins[ 'toggle-menu-mobile/toggle-menu-mobile.php' ][ 'update-supported' ] = true;
    $plugins[ 'toggle-menu-mobile/toggle-menu-mobile.php' ][ 'id' ] = 'gc.com/plugins/togglemenumobile';
    $plugins[ 'toggle-menu-mobile/toggle-menu-mobile.php' ][ 'slug' ] = 'toggle-menu-mobile';
    $plugins[ 'toggle-menu-mobile/toggle-menu-mobile.php' ][ 'plugin' ] = 'toggle-menu-mobile/toggle-menu-mobile.php';
    $plugins[ 'toggle-menu-mobile/toggle-menu-mobile.php' ][ 'url' ] = 'https://graphiccaffeine.com/fcm-custom-plugins/toggle-menu-mobile/';
  }
  return $plugins;
}, 100 );

global $toggle_mobile_detect;
$toggle_mobile_detect = false;

	//function setup_toggle_mobile_plugin(){
		global $wp_version;
		if ( is_admin() && $wp_version < 3.8 )
			wp_die( __( 'This Plugin Requires WordPress 3.8 or higher: Could Not Install!' ) );
		if ( $wp_version >= 3.8 ){
			$options 	 = get_option( 'mobile_menu_settings' );
			$usewpMobile = isset($options['desktop_menu_wp_mobile']) && $options['desktop_menu_wp_mobile'] == '1' ? true : false;
			if( ( $usewpMobile && isMobileDevice() ) || !$usewpMobile ){
				add_action( 'wp_enqueue_scripts', 'toggle_responsive_menu_scripts');
				add_action( 'wp_head', 'toggle_responsive_menu_meta',1 );
				add_action( 'wp_login_head', 'toggle_responsive_menu_meta',1 );
				add_action( 'wp_footer', 'toggle_responsive_menu_header_hook' );
			}
			register_nav_menu( 'toggle-mobile-menu', 'Toggle Mobile Menu' );
		}
		add_filter( 'body_class', 'toggle_body_class' );
	//}
	//add_action('init', 'setup_toggle_mobile_plugin', 11);
	
	function toggle_responsive_menu_meta(){
		echo '<meta content="width=device-width,initial-scale=1.0" name="viewport">'."\n";
		echo '<meta content="telephone=no" name="format-detection">'."\n";
		echo '<meta content="address=no" name="format-detection">'."\n";
	}
	
	function toggle_menu_dynaminc_css_custom() {
		check_ajax_referer( 'toggle_menu_style_verify', 'nonce', true );  
		$expires = 60*60*24;
		header("Pragma: public");
		header("Cache-Control: maxage=".$expires);
		header('Expires: ' . gmdate('D, d M Y H:i:s', time()+$expires) . ' GMT');
		header('Content-type: text/css');
		$options 			= get_option( 'mobile_menu_settings' );
		$mobile_menu_class 	= isset($options['mobile_menu_class']) ? $options['mobile_menu_class'] : 'nav-menu-mobile';
		$menu_icon_height 	= isset($options['menu_icon_height']) ? $options['menu_icon_height'] : '32';
		$menu_icon_color 	= isset($options['menu_icon_color']) ? $options['menu_icon_color'] : '#FFFFFF';
		$menu_icon_opacity 	= isset($options['menu_icon_opacity']) ? $options['menu_icon_opacity'] : '0.5';
		$hextorgb 			= ToggleMenuSettingsPage::hex2RGB($menu_icon_color,true);
		$menu_icon_output 	= $hextorgb !== false ? 'rgba('.$hextorgb.', '.$menu_icon_opacity.')' : 'rgba(255, 255, 255, '.$menu_icon_opacity.')';
		$menu_icon_outputH 	= $hextorgb !== false ? 'rgba('.$hextorgb.', 0.8)' : 'rgba(255, 255, 255, 0.8)';
		$desktop_menu_class = isset($options['desktop_menu_class']) ? $options['desktop_menu_class'] : 'nav-menu-desktop';
		$mobile_menu_name 	= isset($options['mobile_menu_selected']) ? $options['mobile_menu_selected'] : 'mobile'; 
		$desktop_menu_name 	= isset($options['desktop_menu_selected']) ? $options['desktop_menu_selected'] : 'primary'; 
		$menu_toggle_point	= isset($options['mobile_menu_toggle_point']) && (int) $options['mobile_menu_toggle_point'] > 0 ? (int) $options['mobile_menu_toggle_point'] : 960;
		$menu_toggle_min	= ($menu_toggle_point - 1);
		$menu_hover_color	= isset($options['mobile_menu_hover_color']) && $options['mobile_menu_hover_color'] != '' ? $options['mobile_menu_hover_color'] : '#107209';
		$menuBGColor		= isset($options['mobile_menu_bg_color']) && $options['mobile_menu_bg_color'] != '' ? $options['mobile_menu_bg_color'] : '#1D1D1D';
		$data = '
		#mobile-menu-plugin-toggle {float: right;position: fixed;top: 0px;right: 0px;width: 65px;height: 65px;z-index:100001; text-align:right;padding:10px;}
		#mobile-menu-plugin-toggle a{display: inline-block;padding: 0 2px;margin: 0;outline: none;text-decoration: none;vertical-align: middle;}
		#mobile-menu-plugin-toggle a .dashicons {color: '.$menu_icon_output.';height: '.$menu_icon_height.'px;width: '.$menu_icon_height.'px;font-size: '.$menu_icon_height.'px;vertical-align: baseline;text-decoration: none;display: block;}
		#mobile-menu-plugin-toggle a .dashicons:hover {color: '.$menu_icon_outputH.';}
		#mobile-menu-plugin-toggle-img{display:none;}
		.mobile-menu-plugin-top-search {border-bottom: 1px solid #333;-moz-box-shadow: 0 0 10px #000;-webkit-box-shadow: 0 0 10px #000;box-shadow: 0 0 10px #000;text-align:center;top:-150px;position:fixed;height:'.($menu_icon_height+1).'px;width:100%;background: rgba(25, 25, 25, 1);z-index: 10001;border-top: 1px solid #333;padding-bottom: 3px;;padding-top: 3px;box-sizing: border-box;-moz-box-sizing: border-box;-webkit-box-sizing: border-box;}
		.mobile-menu-plugin-top-search .search-form {height: 100%;}
		.mobile-menu-plugin-top-search .search-submit {border: 0 none;height: initial;margin: 4px;text-transform: uppercase;color: #666;cursor: pointer;padding: 5px 10px;line-height: '.($menu_icon_height-6).'px;}
		.mobile-menu-plugin-top-search .search-submit:hover {background: #ccc;}
		.mobile-menu-plugin-top-search input#searchsubmit { background: #DFDFDF; box-sizing: border-box; line-height: 1em; font-size: 1em; height: '.($menu_icon_height-6).'px; border: 0 none; width: 12%;min-width: 68px; }
		.mobile-menu-plugin-top-search .search-field {width: 70%;height: '.($menu_icon_height-6).'px;border: 0 none;margin: 4px;padding: 4px;}
		.mobile-menu-plugin-top-search #searchform label.screen-reader-text { display: none; }
		.mobile-menu-plugin-top-search input#s { line-height: 1em; border: 0 none; box-sizing: border-box; width: 50%; height: '.($menu_icon_height-6).'px; }
		.mobile-menu-plugin-top-search form#searchform { height: '.($menu_icon_height-6).'px; }
		html.mobile-push-right{overflow-x:hidden;}
		.mobile_menu_zip_pointer {border: 10px solid transparent;border-right-color: #fff;position: absolute;right: 0px;top: 7px;}
		.mobile_menu_submenu_pointer {display: inline-block;color:rgba(255,255,255,.25);padding: 0 15px 0 5px;float:right;}
		'.$desktop_menu_class.'{display:block;}
		@media (max-width: '.$menu_toggle_min.'px) {
			body {margin-top: '.$menu_icon_height.'px !important;background-position: center '.$menu_icon_height.'px;}
			#mobile-menu-plugin-toggle img {margin: 8px 4px 7px 4px;max-height: 25px;opacity: .35;}
			#mobile-menu-plugin-toggle img:hover {opacity: .8;}
			#mobile-menu-plugin-popout {position: fixed;height: 100%;width: 250px;background: '.$menuBGColor.';color: white;top: 0px;left: -250px;overflow:auto;z-index:100000;display:block;margin-top: '.$menu_icon_height.'px;}
			#mobile-menu-plugin-toggle {float: initial;position: fixed;top: 0;right: 0;width: 100%;height: '.($menu_icon_height + 1).'px;z-index:100001;text-align: left;padding: 0;background: '.$menuBGColor.';}
			'.$mobile_menu_class.' {margin:0;padding:0; list-style-type:none;overflow: hidden;}
			'.$mobile_menu_class.' li {-moz-box-sizing:border-box;-webkit-box-sizing:border-box;box-sizing:border-box; padding:0;width:100%;font-family: sans-serif;margin-bottom: 0;}
			'.$mobile_menu_class.' li a:hover{background: '.$menu_hover_color.';}
			'.$mobile_menu_class.' li a {position: relative; -moz-box-sizing:border-box;-webkit-box-sizing:border-box;box-sizing:border-box;color:#FFF;text-decoration:none;display: block;padding: 10px 0 10px 6px;font-size:14px;border-bottom:1px solid #eee;}
			'.$mobile_menu_class.' li.current_page_item a:hover{}
			'.$mobile_menu_class.' li.current_page_item a{}
			.tgl-temp{display:none;}
			'.$desktop_menu_class.'{display:none !important;}
			#mobile-menu-plugin-popout .sub-menu{list-style-type:none;padding-left: 0;border-bottom-width: 2px;border-bottom-style: solid;border-bottom-color: rgb(238, 238, 238);}
			#mobile-menu-plugin-popout .sub-menu li a{padding-left:15px;border-bottom: 1px solid #242424;}
			#mobile-menu-plugin-popout .sub-menu li {}
			.mobile-menu-plugin-popout-sub a:before{content:"\00a0\00a0\00bb\00a0";}
		}
		@media screen and (min-width: '.$menu_toggle_point.'px) { 
			#mobile-menu-plugin-toggle {display:none;}
			#mobile-menu-plugin-popout{display:none;}
			'.$desktop_menu_class.'{display:initial;}
		} 		
		';
		echo $data;
		exit;
	}
	add_action('wp_ajax_toggle_menu_dynaminc_css_custom', 'toggle_menu_dynaminc_css_custom');
	add_action('wp_ajax_nopriv_toggle_menu_dynaminc_css_custom', 'toggle_menu_dynaminc_css_custom');
	
	function toggle_responsive_menu_scripts() {
		$menu_toggle_point	= isset($options['mobile_menu_toggle_point']) && (int) $options['mobile_menu_toggle_point'] > 0 ? (int) $options['mobile_menu_toggle_point'] : 960;
		$menu_icon_height	= isset($options['menu_icon_height']) && (int) $options['menu_icon_height'] > 0 ? (int) $options['menu_icon_height'] : 32;
		$ajax_nonce 		= wp_create_nonce( 'toggle_menu_style_verify' );
		wp_enqueue_style( 'dashicons');
		wp_enqueue_style( 'toggle-menu-dynamic',admin_url('admin-ajax.php').'?action=toggle_menu_dynaminc_css_custom&nonce='.$ajax_nonce,array('dashicons'),null);
		wp_enqueue_script( 'responsive-menu-toggle-script', plugins_url( 'js/toggle.js' , __FILE__ ) , array( 'jquery' ), 'toggle-1.0', false );
		wp_localize_script( 'responsive-menu-toggle-script', 'responsiveMenuToggleScript' , array( 'mobile_toggle_width_point' => $menu_toggle_point, 'menu_icon_height' => $menu_icon_height ) );
	}

	function toggle_responsive_menu_header_hook(){
		$options 			= get_option( 'mobile_menu_settings' );
		$mobile_menu_class 	= isset($options['mobile_menu_class']) ? str_replace(array('.','#'),array('',''),$options['mobile_menu_class']) : 'nav-menu-mobile';
		$desktop_menu_class = isset($options['desktop_menu_class']) ? str_replace(array('.','#'),array('',''),$options['desktop_menu_class']) : 'nav-menu-desktop';
		$mobile_menu_name 	= isset($options['mobile_menu_selected']) ? $options['mobile_menu_selected'] : 'mobile'; 
		$desktop_menu_name 	= isset($options['desktop_menu_selected']) ? $options['desktop_menu_selected'] : 'primary';
		$contactPage		= isset($options['desktop_menu_contact_page']) && $options['desktop_menu_contact_page']!='' ? $options['desktop_menu_contact_page'] : '#';
		$showHome			= isset($options['desktop_menu_show_home']) && $options['desktop_menu_show_home']!=''  ? 1 : 0;
		$showContact		= isset($options['desktop_menu_show_contact']) && $contactPage != '' ? 1 : 0;
		$showSearch			= isset($options['desktop_menu_show_search']) && $options['desktop_menu_show_search']!=''  ? 1 : 0;
		$wpMobileOnly		= isset($options['desktop_menu_wp_mobile']) && $options['desktop_menu_wp_mobile']!=''  ? 1 : 0;
		$outHTML 			= array();
		$outHTML[] 			= '<div id="mobile-menu-plugin-toggle">';
        $outHTML[]			= '	<a href="#show-menu" class="mobile-menu-plugin-toggle-menu" title="show/hide menu" ><span class="dashicons dashicons-menu"></span></a>';
		$homeText			= '	<a href="'.home_url().'" class="mobile-menu-plugin-toggle-home" title="home"><span class="dashicons dashicons-admin-home" /></span></a>';
		$searchText			= '	<a href="#search" class="mobile-menu-plugin-toggle-search"><span class="dashicons dashicons-search"></span></a>';
		$contactHREF 		= $contactPage != '' && $contactPage!='#' ? get_permalink($contactPage) : $contactPage;
		$contactText		= '	<a href="'.$contactHREF.'" class="mobile-menu-plugin-toggle-email"><span class="dashicons dashicons-email-alt"></span></a>';
        if($showHome){ 		$outHTML[] = apply_filters('toggle_mobile_menu_home_link',$homeText,'#show-menu',plugins_url( 'images/home.png' , __FILE__ ));}
        if($showSearch){ 	$outHTML[] = apply_filters('toggle_mobile_menu_search_link',$searchText,home_url(),plugins_url( 'images/search.png' , __FILE__ ));}
        if($showContact){ 	$outHTML[] = apply_filters('toggle_mobile_menu_contact_link',$contactText,'#search',plugins_url( 'images/email.png' , __FILE__ ));}
		$additionalIcons	= has_filter('toggle_mobile_menu_add_item') ? apply_filters('toggle_mobile_menu_add_item', $options) : array();
		if(is_array($additionalIcons) && !empty($additionalIcons)){
			foreach($additionalIcons as $key => $item)
				$outHTML[] = $item;
		}
		$outHTML[]			= '</div>';
		if($showSearch){
			$outHTML[]		= '<div class="mobile-menu-plugin-top-search">'.get_search_form(false).'</div>';
		}
		$outHTML[]			= '<div id="mobile-menu-plugin-popout">'.wp_nav_menu( array( 'theme_location' => $mobile_menu_name, 'menu_class' => $mobile_menu_class, 'echo' => false ) ).'</div>';
		echo apply_filters('toggle_mobile_menu_full_html',implode("\n",$outHTML));
	}
	function toggle_mobile_menu_add_item_filter($options = array()){
		$icon_size	= isset($options['menu_icon_height']) && (int) $options['menu_icon_height'] > 0 ? (int) $options['menu_icon_height'] : 32;
		$newArr = array();
		//$newArr[] = '<a href="'.get_bloginfo('url').'/my-account/" class="mobile-menu-plugin-toggle-account" style="" title="account" rel="nofollow"><span class="dashicons dashicons-id"></span></a>';
		if(current_user_can('manage_options')){
			$newArr[] = '<a href="'.get_bloginfo('url').'/wp-admin/" class="mobile-menu-plugin-toggle-admin" title="admin" rel="nofollow"><span class="dashicons dashicons-dashboard"></span></a>';
		}
		//$newArr[] = '<a href="'.get_bloginfo('url').'/cart/" class="mobile-menu-plugin-toggle-cart menu-mini-top-title" style="right: '.(5).'px;position: absolute;" title="cart"><span class="dashicons dashicons-cart"></span></a>';
		//$newArr[] = '<a href="'.get_bloginfo('url').'/site-map-page/" class="mobile-menu-plugin-toggle-help" style="right: 0px;position: absolute;" title="Site Map"><span class="dashicons dashicons-editor-help"></span></a>';
	
		return $newArr;
	}
	add_filter('toggle_mobile_menu_add_item','toggle_mobile_menu_add_item_filter');
	
class ToggleMenuSettingsPage{
    private $options;
    public function __construct(){
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }
    public function add_plugin_page(){
        add_options_page('Mobile Menu', 'Mobile Menu Settings', 'manage_options', 'mobile-setting-admin', array( $this, 'create_admin_page' ));
    }
    public function create_admin_page(){
        $this->options = get_option( 'mobile_menu_settings' );
        echo '<div class="wrap"><h2>Mobile Menu Settings Options Page</h2>'."\n";
        echo '	<form method="post" action="options.php">'."\n";
		settings_fields( 'mobile_option_group' );   
		do_settings_sections( 'mobile-setting-admin' );
		submit_button(); 
        echo '	</form>'."\n";
        echo '</div>'."\n";
    }
    public function page_init(){        
        register_setting('mobile_option_group','mobile_menu_settings',array( $this, 'sanitize' ));
        add_settings_section('mobile_section_id', 'Mobile Menu Settings', array( $this, 'print_section_info' ),'mobile-setting-admin');  
        add_settings_field('mobile_menu_toggle_point', 'Menu Toggle Point',array( $this, 'mobile_menu_toggle_point_callback' ),'mobile-setting-admin','mobile_section_id' );      
        add_settings_field('mobile_menu_selected', 'Mobile Menu',array( $this, 'mobile_menu_selected_callback' ),'mobile-setting-admin','mobile_section_id' );      
        add_settings_field('mobile_menu_class','Mobile Menu Class', array( $this, 'mobile_menu_class_callback' ), 'mobile-setting-admin', 'mobile_section_id');      
        add_settings_field('desktop_menu_selected','Desktop Menu', array( $this, 'desktop_menu_selected_callback' ), 'mobile-setting-admin', 'mobile_section_id');      
        add_settings_field('desktop_menu_class','Desktop Menu Class', array( $this, 'desktop_menu_class_callback' ), 'mobile-setting-admin', 'mobile_section_id');
		add_settings_field('mobile_menu_bg_color','Menu Background Color', array( $this, 'mobile_menu_bg_color_callback' ), 'mobile-setting-admin', 'mobile_section_id');  
		add_settings_field('mobile_menu_hover_color','Menu Hover Color', array( $this, 'mobile_menu_hover_color_callback' ), 'mobile-setting-admin', 'mobile_section_id');  
		add_settings_field('desktop_menu_show_home','Show Home Icon', array( $this, 'desktop_menu_show_home_callback' ), 'mobile-setting-admin', 'mobile_section_id');  
		add_settings_field('desktop_menu_show_search','Show Search Icon', array( $this, 'desktop_menu_show_search_callback' ), 'mobile-setting-admin', 'mobile_section_id');
		add_settings_field('desktop_menu_show_contact','Show Contact Icon', array( $this, 'desktop_menu_show_contact_callback' ), 'mobile-setting-admin', 'mobile_section_id');
		add_settings_field('desktop_menu_contact_page','Conact Page', array( $this, 'desktop_menu_contact_page_callback' ), 'mobile-setting-admin', 'mobile_section_id'); 
		add_settings_field('menu_icon_height','Menu Icon Height',array($this, 'mobile_menu_icon_height_callback'),'mobile-setting-admin','mobile_section_id'); 
		add_settings_field('menu_icon_color','Menu Icon Color',array($this, 'mobile_menu_icon_color_callback'),'mobile-setting-admin','mobile_section_id'); 
		add_settings_field('menu_icon_opacity','Menu Icon Opacity',array($this, 'mobile_menu_icon_opacity_callback'),'mobile-setting-admin','mobile_section_id'); 
		add_settings_field('desktop_menu_wp_mobile','Use mobile detection script?', array( $this, 'desktop_menu_wp_mobile_callback' ), 'mobile-setting-admin', 'mobile_section_id');  
   }
   public function sanitize( $input ){
        $new_input = array();
        if( isset( $input['mobile_menu_toggle_point'] ) ){$new_input['mobile_menu_toggle_point'] = (int)$input['mobile_menu_toggle_point'];}
        if( isset( $input['mobile_menu_selected'] ) ){$new_input['mobile_menu_selected'] = sanitize_text_field( $input['mobile_menu_selected'] );}
        if( isset( $input['mobile_menu_class'] ) ){$new_input['mobile_menu_class'] = sanitize_text_field( $input['mobile_menu_class'] );}
        if( isset( $input['desktop_menu_selected'] ) ){$new_input['desktop_menu_selected'] = sanitize_text_field( $input['desktop_menu_selected'] );}
        if( isset( $input['desktop_menu_class'] ) ){$new_input['desktop_menu_class'] = sanitize_text_field( $input['desktop_menu_class'] );}
        if( isset( $input['desktop_menu_show_home'] ) ){$new_input['desktop_menu_show_home'] = sanitize_text_field( $input['desktop_menu_show_home'] );}
        if( isset( $input['desktop_menu_show_search'] ) ){$new_input['desktop_menu_show_search'] = sanitize_text_field( $input['desktop_menu_show_search'] );}
        if( isset( $input['desktop_menu_show_contact'] ) ){$new_input['desktop_menu_show_contact'] = sanitize_text_field( $input['desktop_menu_show_contact'] );}
        if( isset( $input['desktop_menu_contact_page'] ) ){$new_input['desktop_menu_contact_page'] = sanitize_text_field( $input['desktop_menu_contact_page'] );}
        if( isset( $input['mobile_menu_bg_color'] ) ){$new_input['mobile_menu_bg_color'] = sanitize_text_field( str_replace(' ','',$input['mobile_menu_bg_color']) );}
        if( isset( $input['mobile_menu_hover_color'] ) ){$new_input['mobile_menu_hover_color'] = sanitize_text_field( str_replace(' ','',$input['mobile_menu_hover_color']) );}
	    if( isset( $input['menu_icon_height'] ) ){$new_input['menu_icon_height'] = sanitize_text_field( str_replace(' ','',$input['menu_icon_height']) );}
        if( isset( $input['menu_icon_color'] ) ){$new_input['menu_icon_color'] = sanitize_text_field( str_replace(' ','',$input['menu_icon_color']) );}
        if( isset( $input['menu_icon_opacity'] ) ){$new_input['menu_icon_opacity'] = sanitize_text_field( str_replace(' ','',$input['menu_icon_opacity']) );}
        if( isset( $input['desktop_menu_wp_mobile'] ) ){$new_input['desktop_menu_wp_mobile'] = sanitize_text_field( $input['desktop_menu_wp_mobile'] );}
      return $new_input;
    }
    public function mobile_menu_icon_height_callback(){
        echo '<input type="text" id="menu_icon_height" name="mobile_menu_settings[menu_icon_height]" value="'.(isset( $this->options['menu_icon_height']) && $this->options['menu_icon_height'] !='' ? $this->options['menu_icon_height'] : '30' ).'" /> px';
    }
    public function mobile_menu_icon_color_callback(){
        echo '<input type="text" id="menu_icon_color" name="mobile_menu_settings[menu_icon_color]" value="'.(isset( $this->options['menu_icon_color']) && $this->options['menu_icon_color'] !='' ? $this->options['menu_icon_color'] : '#FFFFFF' ).'" />';
    }
    public function mobile_menu_icon_opacity_callback(){
		$menuarr 	= array();
		$menus  	= array('1'=>'100%','0.9'=>'90%','0.8'=>'80%','0.7'=>'70%','0.6'=>'60%','0.5'=>'50%','0.4'=>'40%','0.3'=>'30%','0.2'=>'20%','0.1'=>'10%','0'=>'0%');
		$selmenu 	= isset( $this->options['menu_icon_opacity'] ) ? esc_attr( $this->options['menu_icon_opacity']) : '0.5';
		foreach($menus as $key => $val)
			$menuarr[] = '<option value="'.$key.'"'.($selmenu == $key ? ' selected' : '').'>'.$val.'</option>';
        echo '<select id="menu_icon_opacity" name="mobile_menu_settings[menu_icon_opacity]">'.implode("\n",$menuarr).'</select>';
    }
    public function print_section_info(){
        print 'Enter your settings below:';
    }
    public function mobile_menu_bg_color_callback(){
        echo '<input type="text" id="mobile_menu_bg_color" name="mobile_menu_settings[mobile_menu_bg_color]" value="'.(isset( $this->options['mobile_menu_bg_color']) && $this->options['mobile_menu_bg_color'] !='' ? $this->options['mobile_menu_bg_color'] : '#1D1D1D' ).'" />';
    }
    public function mobile_menu_hover_color_callback(){
        echo '<input type="text" id="mobile_menu_hover_color" name="mobile_menu_settings[mobile_menu_hover_color]" value="'.(isset( $this->options['mobile_menu_hover_color']) && $this->options['mobile_menu_hover_color'] !='' ? $this->options['mobile_menu_hover_color'] : '#107209' ).'" />';
    }
    public function mobile_menu_toggle_point_callback(){
        echo '<input type="text" id="mobile_menu_toggle_point" name="mobile_menu_settings[mobile_menu_toggle_point]" value="'.(isset( $this->options['mobile_menu_toggle_point']) && (int)$this->options['mobile_menu_toggle_point'] > 0 ? (int)$this->options['mobile_menu_toggle_point'] : '960' ).'" /> px';
    }
    public function desktop_menu_show_home_callback(){
        echo '<input type="checkbox" id="desktop_menu_show_home" name="mobile_menu_settings[desktop_menu_show_home]" value="1" '.checked( $this->options['desktop_menu_show_home'], 1, 0 ).' />';
    }
    public function desktop_menu_show_search_callback(){
        echo '<input type="checkbox" id="desktop_menu_show_search" name="mobile_menu_settings[desktop_menu_show_search]" value="1" '.checked( $this->options['desktop_menu_show_search'], 1, 0 ).' />';
    }
    public function desktop_menu_show_contact_callback(){
        echo '<input type="checkbox" id="desktop_menu_show_contact" name="mobile_menu_settings[desktop_menu_show_contact]" value="1" '.checked( $this->options['desktop_menu_show_contact'], 1 , 0 ).' />';
    }
    public function desktop_menu_wp_mobile_callback(){
        echo '<input type="checkbox" id="desktop_menu_wp_mobile" name="mobile_menu_settings[desktop_menu_wp_mobile]" value="1" '.checked( $this->options['desktop_menu_wp_mobile'], 1, 0 ).' />';
    }
    public function desktop_menu_contact_page_callback(){
		$selpage 	= isset( $this->options['desktop_menu_contact_page'] ) ? (int)$this->options['desktop_menu_contact_page'] : 0;
		$args 		= array('depth'=> 0,'child_of'=> 0,'selected'=> $selpage,'echo'=> 0,'name' => 'mobile_menu_settings[desktop_menu_contact_page]','id' => 'desktop_menu_contact_page','show_option_none'=> 'select one','show_option_no_change'=> null,'option_none_value'=> '#',);
		$pagelist 	= wp_dropdown_pages( $args );
		echo $pagelist; 
    }
    public function mobile_menu_selected_callback(){
		$menuarr	= array();
		$menus  	= get_registered_nav_menus();
		$selmenu 	= isset( $this->options['mobile_menu_selected'] ) ? esc_attr( $this->options['mobile_menu_selected']) : '';
		$menuarr[] = '<option value=""'.($selmenu == '' ? ' selected' : '').'>-- select one --</option>';
		foreach($menus as $key => $val)
			$menuarr[] = '<option value="'.$key.'"'.($selmenu == $key ? ' selected' : '').'>'.$val.'</option>';
        echo '<select id="mobile_menu_selected" name="mobile_menu_settings[mobile_menu_selected]">'.implode("\n",$menuarr).'</select>';
    }
    public function mobile_menu_class_callback(){
        printf('<input type="text" id="mobile_menu_class" name="mobile_menu_settings[mobile_menu_class]" value="%s" />',isset( $this->options['mobile_menu_class'] ) ? esc_attr( $this->options['mobile_menu_class']) : '');
    }
    public function desktop_menu_selected_callback(){
		$menuarr	= array();
		$menus  	= get_registered_nav_menus();
		$selmenu 	= isset( $this->options['desktop_menu_selected'] ) ? esc_attr( $this->options['desktop_menu_selected']) : '';
		$menuarr[]	= '<option value=""'.($selmenu == '' ? ' selected' : '').'>-- select one --</option>';
		foreach($menus as $key => $val)
			$menuarr[] = '<option value="'.$key.'"'.($selmenu == $key ? ' selected' : '').'>'.$val.'</option>';
        echo '<select id="desktop_menu_selected" name="mobile_menu_settings[desktop_menu_selected]">'.implode("\n",$menuarr).'</select>';
    }
    public function desktop_menu_class_callback(){
        printf('<input type="text" id="desktop_menu_class" name="mobile_menu_settings[desktop_menu_class]" value="%s" />',isset( $this->options['desktop_menu_class'] ) ? esc_attr( $this->options['desktop_menu_class']) : '');
    }
	public function hex2RGB($hexStr, $returnAsString = false, $seperator = ',') {
		$hexStr 	= preg_replace("/[^0-9A-Fa-f]/", '', $hexStr);
		$rgbArray 	= array();
		if(strlen($hexStr) == 6){
			$colorVal = hexdec($hexStr);
			$rgbArray['red'] 	= 0xFF & ($colorVal >> 0x10);
			$rgbArray['green'] 	= 0xFF & ($colorVal >> 0x8);
			$rgbArray['blue'] 	= 0xFF & $colorVal;
		}elseif(strlen($hexStr) == 3){ 
			$rgbArray['red'] 	= hexdec(str_repeat(substr($hexStr, 0, 1), 2));
			$rgbArray['green'] 	= hexdec(str_repeat(substr($hexStr, 1, 1), 2));
			$rgbArray['blue'] 	= hexdec(str_repeat(substr($hexStr, 2, 1), 2));
		}else{
			return false; 
		}
		return $returnAsString ? implode($seperator, $rgbArray) : $rgbArray;
	}
}
if( is_admin() ){$my_settings_page = new ToggleMenuSettingsPage();}


// MOBILE DETECTION

function toggle_body_class($classes) {
	if(!class_exists('Mobile_Detect'))
		require_once( 'mobile-detect-class.php');
	global $toggle_mobile_detect;
	if( !is_object( $toggle_mobile_detect ) )
		$toggle_mobile_detect = new Mobile_Detect();
	if( $toggle_mobile_detect->isMobile() )
		$classes[] = 'mobile';
	if( $toggle_mobile_detect->isTablet() )
		$classes[] = 'tablet';
	if( $toggle_mobile_detect->isiOS() )
		$classes[] = 'ios';
	if( $toggle_mobile_detect->isAndroidOS() )
		$classes[] = 'android';
	if( $toggle_mobile_detect->isMobile() || $toggle_mobile_detect->isTablet() )
		$classes[] = 'handheld';
	if( !$toggle_mobile_detect->isMobile() && !$toggle_mobile_detect->isTablet() )
		$classes[] = 'desktop';
	return $classes;
}

function isMobileDevice(){
	if(!class_exists('Mobile_Detect'))
		require_once( 'mobile-detect-class.php');
	global $toggle_mobile_detect;
	if( !is_object( $toggle_mobile_detect ) )
		$toggle_mobile_detect = new Mobile_Detect();
	//echo '<!--'.$toggle_mobile_detect->isMobile().'|'.$toggle_mobile_detect->isTablet().'-->';
	if( $toggle_mobile_detect->isMobile() || $toggle_mobile_detect->isTablet() )
		return true;
	return false;
}